@@ -36,11 +36,19 @@ import cairo
 import time
 import md5
 
+
 from h_deb import *
 from h_config_sl import *
 from h_UI_searchDialog import *
 from h_UI_mainMenuDialog import *
 from h_UI_detailsWindow import *
+
+try:
+    from h_UI_selectContact import *
+    send_to_contact = 1
+except:
+    send_to_contact = 0
+
 from GpsManager import *
 from BuildPluginsList import *
 
@@ -471,6 +479,66 @@ class UI(hildon.StackableWindow):
     def get_version(self):
         return version
 
+
+
+
+
+
+
+
+
+
+
+    # ------------------ SMS
+
+    def send_to_contact_present(self):
+        return send_to_contact
+    def send_to_contact_dialog(self,str_to_send):
+        bt_sms = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                               hildon.BUTTON_ARRANGEMENT_VERTICAL,"SMS")
+        bt_sms.connect("clicked", self.send_to_contact_step1, str_to_send)
+        bt_sms.show_all()
+        return bt_sms
+    def send_to_contact_step1(self, w, str_to_send):
+        s = SelectContact(self,str_to_send)
+    def send_to_contact_step2(self, telNr, str_to_send):
+        if telNr=="" or str_to_send == "":
+            return None
+
+        d = gtk.Dialog()
+        d.set_title("Share via SMS")
+
+        d.vbox.pack_start( gtk.Label("Send to: %s"%telNr), False)
+
+        text = gtk.Entry()
+        text.set_text( str_to_send)
+        d.vbox.pack_start( text, True)
+
+        bt_send = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                               hildon.BUTTON_ARRANGEMENT_VERTICAL,"Send SMS")
+        bt_send.connect("clicked", self.send_to_contact_step3, telNr,text, d)
+        d.vbox.pack_start( bt_send, False )
+
+        d.show_all()
+        d.run()
+        d.destroy()
+
+    def send_to_contact_step3(self, w, number, text, dialog):
+        message = text.get_text()
+
+        cmd = "smssend -s -v 167 -m \"%s\" -n %s &" % (message.replace("\"", "'"), number)
+        os.system(cmd)
+
+
+        dialog.destroy()
+        print "SMS send! tel:[%s] message[%s]" % (number, message)
+
+
+
+    # ------------------ SMS
+
+
+
     def set_autorotate_for_object_same_as_UI(self, obj):
         try:
             mode = self.window_rotate.get_mode()
@@ -1153,8 +1221,14 @@ gobject.type_register(PluginsLayer)
 
 
 
-
 if __name__ == "__main__":
+    print "ebook test --"
+
+    #s = SelectContact()
+    #print s.runIt()
+
+
+
     config_load( CONFIG )
     u = UI()
     u.show_all()
